prima: WLAN Driver Release 3.2.0.9
diff --git a/CORE/WDI/CP/inc/wlan_qct_wdi_i.h b/CORE/WDI/CP/inc/wlan_qct_wdi_i.h
index 8ac7fba..f5e90e1 100644
--- a/CORE/WDI/CP/inc/wlan_qct_wdi_i.h
+++ b/CORE/WDI/CP/inc/wlan_qct_wdi_i.h
@@ -363,8 +363,8 @@
   /* WLAN FTM Command request */
   WDI_FTM_CMD_REQ            = 59,
 
-  /*WLAN START INNAV MEAS Request*/
-  WDI_START_INNAV_MEAS_REQ   = 60,
+  /*WLAN START OEM_DATA MEAS Request*/
+  WDI_START_OEM_DATA_REQ   = 60,
   /* WLAN host resume request */
   WDI_HOST_RESUME_REQ      = 61,
   
@@ -604,8 +604,8 @@
   /*Delete Self STA Response*/
   WDI_DEL_STA_SELF_RESP       = 57,
 
-  /*WLAN START INNAV MEAS Response*/
-  WDI_START_INNAV_MEAS_RESP   = 58,
+  /*WLAN START OEM_DATA Response*/
+  WDI_START_OEM_DATA_RESP   = 58,
 
   /* WLAN host resume request */
   WDI_HOST_RESUME_RESP        = 59,
@@ -654,8 +654,8 @@
 
   WDI_TSM_STATS_RESP                            = 74,
   /* GTK Rekey Offload */
-  WDI_GTK_OFFLOAD_RESP                    = 75, 
-  WDI_GTK_OFFLOAD_GETINFO_RESP         = 76, 
+  WDI_GTK_OFFLOAD_RESP                          = 75, 
+  WDI_GTK_OFFLOAD_GETINFO_RESP                  = 76, 
 
   WDI_SET_TM_LEVEL_RESP                         = 77,
 
@@ -2442,6 +2442,24 @@
   WDI_EventInfoType*     pEventData
 );
 
+#ifdef FEATURE_OEM_DATA_SUPPORT
+/**
+ @brief Process Start Oem Data Request function (called when Main 
+        FSM allows it)
+ 
+ @param  pWDICtx:         pointer to the WLAN DAL context 
+         pEventData:      pointer to the event information structure 
+  
+ @see
+ @return Result of the function call
+*/
+WDI_Status
+WDI_ProcessStartOemDataReq
+( 
+  WDI_ControlBlockType*  pWDICtx,
+  WDI_EventInfoType*     pEventData
+);
+#endif
 
 /**
  @brief Process Host Resume Request function (called when Main 
@@ -3646,6 +3664,24 @@
   WDI_EventInfoType*     pEventData
 );
 
+#ifdef FEATURE_OEM_DATA_SUPPORT
+/**
+ @brief Start Oem Data Rsp function (called when a 
+        response is being received over the bus from HAL)
+ 
+ @param  pWDICtx:         pointer to the WLAN DAL context 
+         pEventData:      pointer to the event information structure 
+  
+ @see
+ @return Result of the function call
+*/
+WDI_Status
+WDI_ProcessStartOemDataRsp
+( 
+  WDI_ControlBlockType*  pWDICtx,
+  WDI_EventInfoType*     pEventData
+);
+#endif
 
  /**
  @brief WDI_ProcessHostResumeRsp function (called when a